@@ -92,6 +92,7 @@ class RangerForestRegressor(BaseRangerForest, RegressorMixin, BaseEstimator):
     def __init__(
         self,
         n_estimators=100,
+        *,
         verbose=False,
         mtry=0,
         importance="none",
@@ -310,6 +311,7 @@ class RangerForestRegressor(BaseRangerForest, RegressorMixin, BaseEstimator):
 
         forest = self._get_terminal_node_forest(X)
         terminal_nodes = np.array(forest["predictions"]).astype(int)
+        terminal_nodes = np.atleast_2d(terminal_nodes)
         node_values = 0.0 * terminal_nodes
         for tree in range(self.n_estimators):
             node_values[:, tree] = self.random_node_values_[
